@@ -11,28 +11,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import eventlet
+import eventlet  # noqa
 eventlet.monkey_patch()
 
-import datetime
-import time
-
 import contextlib
 import copy
+import datetime
 import json
 import os
-import pytz
 import shutil
-import six
-from six.moves import urllib
 import tempfile
+import time
 import unittest
 
 import mock
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
 from oslo_utils import timeutils
+import pytz
 import requests
+import six
+from six.moves import urllib
 
 from ironic_inspector.common import ironic as ir_utils
 from ironic_inspector.common import swift
@@ -58,6 +57,7 @@ enable_setting_ipmi_credentials = True
 [DEFAULT]
 debug = True
 auth_strategy = noauth
+introspection_delay = 0
 [database]
 connection = sqlite:///%(db_file)s
 [processing]
@@ -561,6 +561,7 @@ class Test(Base):
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         status = self.call_get_status(self.uuid)
+        inspect_started_at = timeutils.parse_isotime(status['started_at'])
         self.check_status(status, finished=True)
 
         res = self.call_reapply(self.uuid)
@@ -568,6 +569,13 @@ class Test(Base):
         self.assertEqual('', res.text)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
+        status = self.call_get_status(self.uuid)
+        self.check_status(status, finished=True)
+
+        # checks the started_at updated in DB is correct
+        reapply_started_at = timeutils.parse_isotime(status['started_at'])
+        self.assertLess(inspect_started_at, reapply_started_at)
+
         # reapply request data
         get_mock.assert_called_once_with(self.uuid,
                                          suffix='UNPROCESSED')
